<?php
/**
 * @copyright	Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_HZEXEC_') or die();

/**
 * Media Component Manager Model
 *
 * @package		Joomla.Administrator
 * @subpackage	com_media
 * @since 1.5
 */
class MediaModelManager extends JModelLegacy
{

	function getState($property = null, $default = null)
	{
		static $set;

		if (!$set)
		{
			$folder = Request::getVar('folder', '', '', 'path');
			$this->setState('folder', $folder);

			$fieldid = Request::getCmd('fieldid', '');
			$this->setState('field.id', $fieldid);

			$parent = str_replace("\\", "/", dirname($folder));
			$parent = ($parent == '.') ? null : $parent;
			$this->setState('parent', $parent);
			$set = true;
		}

		return parent::getState($property, $default);
	}

	/**
	 * Image Manager Popup
	 *
	 * @param string $listFolder The image directory to display
	 * @since 1.5
	 */
	function getFolderList($base = null)
	{
		// Get some paths from the request
		if (empty($base))
		{
			$base = COM_MEDIA_BASE;
		}
		//corrections for windows paths
		$base = str_replace(DIRECTORY_SEPARATOR, '/', $base);
		$com_media_base_uni = str_replace(DIRECTORY_SEPARATOR, '/', COM_MEDIA_BASE);

		// Get the list of folders
		$folders = Filesystem::directories($base, '.', true, true);

		Document::setTitle(Lang::txt('COM_MEDIA_INSERT_IMAGE'));

		// Build the array of select options for the folder list
		$options[] = Html::select('option', "", "/");

		foreach ($folders as $folder)
		{
			$folder = str_replace($com_media_base_uni, "", str_replace(DIRECTORY_SEPARATOR, '/', $folder));
			$value  = substr($folder, 1);
			$text   = str_replace(DIRECTORY_SEPARATOR, "/", $folder);
			$options[] = Html::select('option', $value, $text);
		}

		// Sort the folder list array
		if (is_array($options))
		{
			sort($options);
		}

		// Get asset and author id (use integer filter)
		$asset  = Request::getInt('asset', 0);
		$author = Request::get('author', 0);

		// Create the drop-down folder select list
		$list = Html::select('genericlist',  $options, 'folderlist', 'class="inputbox" size="1" onchange="ImageManager.setFolder(this.options[this.selectedIndex].value, '.$asset.', '.$author.')" ', 'value', 'text', $base);

		return $list;
	}

	function getFolderTreeJoomla($base = null)
	{
		// Get some paths from the request
		if (empty($base))
		{
			$base = COM_MEDIA_BASE;
		}

		$mediaBase = str_replace(DIRECTORY_SEPARATOR, '/', COM_MEDIA_BASE.'/');

		// Get the list of folders
		$folders = Filesystem::directories($base, '.', true, true);

		$tree = array();

		foreach ($folders as $folder)
		{
			$folder   = str_replace(DIRECTORY_SEPARATOR, '/', $folder);
			$name     = substr($folder, strrpos($folder, '/') + 1);
			$relative = str_replace($mediaBase, '', $folder);
			$absolute = $folder;
			$path     = explode('/', $relative);
			$node     = (object) array('name' => $name, 'relative' => $relative, 'absolute' => $absolute);

			$tmp = &$tree;
			for ($i=0, $n=count($path); $i<$n; $i++)
			{
				if (!isset($tmp['children']))
				{
					$tmp['children'] = array();
				}

				if ($i == $n-1)
				{
					// We need to place the node
					$tmp['children'][$relative] = array('data' =>$node, 'children' => array());
					break;
				}

				if (array_key_exists($key = implode('/', array_slice($path, 0, $i+1)), $tmp['children']))
				{
					$tmp = &$tmp['children'][$key];
				}
			}
		}
		$tree['data'] = (object) array('name' => Lang::txt('COM_MEDIA_MEDIA'), 'relative' => '', 'absolute' => $base);

		return $tree;
	}

	function getFolderTree($base = null)
	{
		// Get some paths from the request
		if (empty($base))
		{
			$base = COM_MEDIA_BASE;
		}

		$mediaBase = str_replace(DIRECTORY_SEPARATOR, '/', COM_MEDIA_BASE.'/');

		// convert splfileinfo instance into the structure the view wants. return the relative and parent path as well since it's useful to find where the node belongs
		$mkData = function($fi) use($mediaBase)
		{
			$rel = preg_replace('#^'.preg_quote($mediaBase).'\/?#', '', $fi);
			$lastSlash = strrpos($rel, DIRECTORY_SEPARATOR);
			return array(array(
				'data' => (object)array(
					'name'     => preg_replace('#[.].*?$#', '', $fi->getBaseName()),
					'relative' => $rel,
					'absolute' => (string)$fi
				),
				'children' => array()
			), $rel, $lastSlash ? substr($rel, 0, $lastSlash) : '');
		};

		list($path) = $mkData(new SplFileInfo($base));

		foreach (new RecursiveIteratorIterator(new RecursiveDirectoryIterator($base), RecursiveIteratorIterator::SELF_FIRST) as $file)
		{
			// skip hidden files and non-directories
			if (substr($file->getFileName(), 0, 1) == '.' || !$file->isDir())
			{
				continue;
			}
			list($data, $rel, $parent) = $mkData($file);

			// find a place to put the node by walking through parents
			$pos =& $path;
			if (($parents = explode(DIRECTORY_SEPARATOR, $parent)))
			{
				foreach ($parents as $idx=>$par)
				{
					if ($key = implode(DIRECTORY_SEPARATOR, array_slice($parents, 0, $idx + 1)))
					{
						$pos =& $pos['children'][$key];
					}
				}
			}
			$pos['children'][$rel] = $data;
		}

		// recursive natural sort
		$naturalSort = function(&$node) use(&$naturalSort) {
			uksort($node['children'], function($a, $b) { return strcasecmp($a, $b); } );
			$node['children'] = array_map($naturalSort, $node['children']);
			return $node;
		};

		return $naturalSort($path);
	}
}
