<?php
/**
 * @package		Joomla.Site
 * @subpackage	com_users
 * @copyright	Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_HZEXEC_') or die();

/**
 * Base controller class for Users.
 *
 * @package		Joomla.Site
 * @subpackage	com_users
 * @since		1.5
 */
class UsersController extends JControllerLegacy
{
	/**
	 * Method to display a view.
	 *
	 * @param	boolean			If true, the view output will be cached
	 * @param	array			An array of safe url parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return	JController		This object to support chaining.
	 * @since	1.5
	 */
	public function display($cachable = false, $urlparams = false)
	{
		// Get the document object.
		$document = Document::instance();

		// Set the default view name and format from the Request.
		$vName   = Request::getCmd('view', 'login');
		$vFormat = Document::getType();
		$lName   = Request::getCmd('layout', 'default');

		if ($view = $this->getView($vName, $vFormat))
		{
			// Do any specific processing by view.
			switch ($vName) {
				case 'registration':
					App::abort(403, Lang::txt('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN'));
					return;

					// If the user is already logged in, redirect to the profile page.
					if (User::get('guest') != 1)
					{
						// Redirect to profile page.
						$this->setRedirect(Route::url('index.php?option=com_users&view=profile', false));
						return;
					}

					// Check if user registration is enabled
					if (Component::params('com_users')->get('allowUserRegistration') == 0)
					{
						// Registration is disabled - Redirect to login page.
						$this->setRedirect(Route::url('index.php?option=com_users&view=login', false));
						return;
					}

					// The user is a guest, load the registration model and show the registration page.
					$model = $this->getModel('Registration');
					break;

				// Handle view specific models.
				case 'profile':
					App::abort(403, Lang::txt('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN'));
					return;

					// If the user is a guest, redirect to the login page.
					if (User::get('guest') == 1)
					{
						// Redirect to login page.
						$this->setRedirect(Route::url('index.php?option=com_users&view=login', false));
						return;
					}
					$model = $this->getModel($vName);
					break;

				// Handle the default views.
				case 'login':
					$model = $this->getModel($vName);
					break;

				case 'reset':
					// If the user is already logged in, redirect to the profile page.
					if (User::get('guest') != 1)
					{
						// Redirect to profile page.
						$this->setRedirect(Route::url('index.php?option=com_members&task=myaccount', false));
						return;
					}

					$model = $this->getModel($vName);
					break;

				case 'remind':
					// If the user is already logged in, redirect to the profile page.
					if (User::get('guest') != 1)
					{
						// Redirect to profile page.
						$this->setRedirect(Route::url('index.php?option=com_members&task=myaccount', false));
						return;
					}

					$model = $this->getModel($vName);
					break;

				default:
					$model = $this->getModel('Login');
					break;
			}

			// Push the model into the view (as default).
			$view->setModel($model, true);
			$view->setLayout($lName);

			// Push document object into the view.
			$view->assignRef('document', $document);

			$view->display();
		}
	}
}
